@@ -52,10 +52,10 @@ samplephi <- function(phi,stimuli, antibodies, tps, reps, dat, searchstatespace=
 	thetax <- Ltmplist$theta
 	Ltmp[Ltmp==Inf] <- 0
 	Ltmp[Ltmp==-Inf] <- 0
-	Lnew <- sum(Ltmp)
+	Lnew <- sum(Ltmp, na.rm=TRUE)
 	bicnew <- get.bic(phi.n,Lnew,length(dat))
 	aicnew <- get.aic(phi.n,Lnew)
-	if(priortype %in% c("laplaceinhib","laplace","scalefree"))
+	if(priortype %in% c("laplaceinhib","laplace","scalefree","uniform"))
 		prnew <- prior(phi.n, lambda, B, Z, gam, it, K, priortype)
 	else
 		prnew <- 0
@@ -71,7 +71,7 @@ samplephi <- function(phi,stimuli, antibodies, tps, reps, dat, searchstatespace=
 		aicnew <- L.res$aic	
 	}
 	# if prior is given
-	if(priortype %in% c("laplaceinhib","laplace","scalefree")) {
+	if(priortype %in% c("laplaceinhib","laplace","scalefree","uniform")) {
 		postnew <- Lnew + prnew
 	} else {
 		postnew <- NULL
